==> flutter_flavorizr-2.0.0.tar.gz: lib/processors/commons/shell_processor.dart <==
/*
 * Copyright (c) 2021 MyLittleSuite
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

import 'dart:io';

import 'package:flutter_flavorizr/processors/commons/abstract_processor.dart';

class ShellProcessor extends AbstractProcessor<void> {
  final String _path;
  final String? workingDirectory;
  final List<String> _args;

  ShellProcessor(
    this._path,
    this._args, {
    this.workingDirectory,
  });

  @override
  void execute() => Process.runSync(
        _path,
        _args,
        workingDirectory: workingDirectory,
      );

  @override
  String toString() =>
      'ShellProcessor: Running script \'$_path\' with arguments ${_args.join(', ')}';
}

==> flutter_flavorizr-2.1.0.tar.gz: lib/processors/commons/shell_processor.dart <==
/*
 * Copyright (c) 2021 MyLittleSuite
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

import 'dart:io';

import 'package:flutter_flavorizr/parser/models/flavorizr.dart';
import 'package:flutter_flavorizr/processors/commons/abstract_processor.dart';

class ShellProcessor extends AbstractProcessor<void> {
  final String _path;
  final String? workingDirectory;
  final List<String> _args;

  ShellProcessor(
    this._path,
    this._args, {
    this.workingDirectory,
    required Flavorizr config,
  }) : super(config);

  @override
  void execute() {
    ProcessResult result = Process.runSync(
      _path,
      _args,
      workingDirectory: workingDirectory,
    );
    if (result.exitCode != 0) {
      print(result.stderr);
    }
  }

  @override
  String toString() =>
      'ShellProcessor: Running script \'$_path\' with arguments ${_args.join(', ')}';
}
